@@ -33,10 +33,10 @@ async def get_ShipRank(server_type,info,bot,ev):
         bot = get_bot()
         if len(info) == 2:
             param_server,info = await match_keywords(info,servers)
-            if param_server and not param_server == 'cn':
+            if param_server:
                 number_url = number_url_homes[param_server] + "/ship/"
             else:
-                return '请检查服务器是否正确，暂不支持国服'
+                return '请检查服务器是否正确'
         else:
             return '参数似乎出了问题呢'
         shipList = await get_ship_byName(str(info[0]))
@@ -67,16 +67,23 @@ async def get_ShipRank(server_type,info,bot,ev):
                     return '已超时退出'
         else:
             return '找不到船，请确认船名是否正确，可以使用【wws 查船名】查询船只中英文'
-        content = await search_ShipRank_Yuyuko(select_shipId,param_server)
-        if content:                                         #存在缓存，直接出图
-            return await html_to_pic(content, wait=0, viewport={"width": 1300, "height": 100})
-        else:                                               #无缓存，去Number爬
-            content,numbers_data = await search_ShipRank_Numbers(number_url,param_server,select_shipId)
-            if content:
-                await post_ShipRank(numbers_data)     #上报Yuyuko
+        if not param_server == 'cn':
+            content = await search_ShipRank_Yuyuko(select_shipId,param_server)
+            if content:                                         #存在缓存，直接出图
+                return await html_to_pic(content, wait=0, viewport={"width": 1300, "height": 100})
+            else:                                               #无缓存，去Number爬
+                content,numbers_data = await search_ShipRank_Numbers(number_url,param_server,select_shipId)
+                if content:
+                    await post_ShipRank(numbers_data)     #上报Yuyuko
+                    return await html_to_pic(content, wait=0, viewport={"width": 1300, "height": 100})
+                else:
+                    return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~'   
+        else:
+            content = await search_cn_rank(select_shipId,param_server,1)
+            if content:                                         
                 return await html_to_pic(content, wait=0, viewport={"width": 1300, "height": 100})
             else:
-                return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~'   
+                return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~' 
     except (TimeoutError, ConnectTimeout):
         logger.warning(traceback.format_exc())
         ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
@@ -144,4 +151,33 @@ async def post_ShipRank(data):
     except (TimeoutError, ConnectTimeout):
         logger.warning(traceback.format_exc())
     except Exception:
-        logger.error(traceback.format_exc())
\ No newline at end of file
+        logger.error(traceback.format_exc())
+        
+        
+async def search_cn_rank(shipId,server,page):
+    try:
+        content = None
+        async with httpx.AsyncClient(headers=headers) as client:        #查询是否有缓存
+            url = 'https://api.wows.shinoaki.com/wows/rank/ship/server'
+            params = {
+                "server":server,
+                "shipId":int(shipId),
+                "page":int(page)
+            }
+            logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+            resp = await client.get(url, params=params,timeout=None)
+            result = resp.json()
+            logger.success(f"本次请求返回的状态码:{result['code']}")
+            if result['code'] == 200 and result['data']:
+                template = env.get_template("ship-rank-cn.html")
+                result_data = {"data":result['data']}
+                content = await template.render_async(result_data)
+                return content
+            else:
+                return None
+    except (TimeoutError, ConnectTimeout):
+        logger.warning(traceback.format_exc())
+        return None 
+    except Exception:
+        logger.error(traceback.format_exc())
+        return None 
\ No newline at end of file
